@@ -29,14 +29,12 @@ from anyscale.authenticate import get_auth_api_client
 # 2. Import paths are different for different versions of ray
 try:
     from ray.autoscaler._private.providers import (  # pylint:disable=private-import
-        _get_node_provider,
         _NODE_PROVIDERS,
     )
     from ray.autoscaler.node_provider import NodeProvider
 except ModuleNotFoundError:
     from ray.autoscaler.aws.node_provider import NodeProvider
     from ray.autoscaler.node_provider import (  # pylint:disable=private-import
-        get_node_provider as _get_node_provider,
         NODE_PROVIDERS as _NODE_PROVIDERS,
     )
 
@@ -87,7 +85,7 @@ def wrap_api_client_with_retries(api_client: DefaultApi) -> DefaultApi:
     return api_client
 
 
-class AnyscaleInstanceManagerNodeProvider:
+class AnyscaleInstanceManagerNodeProvider(NodeProvider):
     """NodeProvider for managing nodes with instance manager.
     """
 
@@ -99,9 +97,7 @@ class AnyscaleInstanceManagerNodeProvider:
     ) -> None:
         self.provider_config = provider_config
         self.inner_provider_config = provider_config["inner_provider"]
-        self.inner_provider = _get_node_provider(
-            self.inner_provider_config, cluster_name
-        )
+        self.cluster_name = cluster_name
         self.cloud_id = self.inner_provider_config["cloud_id"]
         host = self.inner_provider_config["host"]
         if api_client is None:
@@ -111,16 +107,6 @@ class AnyscaleInstanceManagerNodeProvider:
             )
         else:
             self.api_client = api_client
-        self.is_provider_supported = self._is_provider_supported()
-
-    def _is_provider_supported(self) -> bool:
-        """Currently instance manager only suppport AWS."""
-        # TODO(yifei) move checks from _configure_for_cloud to here
-        return True
-
-    def __getattr__(self, name: str) -> Any:
-        """Implements inheritance from self.inner_provider."""
-        return getattr(self.inner_provider, name)
 
     # Use the same methodology as AnyscalePoolingNodeProvider for the following
     # static methods
@@ -168,12 +154,9 @@ class AnyscaleInstanceManagerNodeProvider:
         return cluster_config
 
     def non_terminated_nodes(self, tag_filters: Dict[str, str]) -> Any:
-        if not self.is_provider_supported:
-            return self.inner_provider.non_terminated_nodes(tag_filters)
-
         non_terminated_nodes_request = NonTerminatedNodesOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             tag_filters=tag_filters,
         )
         resp = self.api_client.non_terminated_nodes_api_v2_instances_non_terminated_nodes_post(
@@ -182,43 +165,28 @@ class AnyscaleInstanceManagerNodeProvider:
         return [instance.instance_id for instance in resp.results]
 
     def is_running(self, node_id: str) -> Any:
-        if not self.is_provider_supported:
-            return self.inner_provider.is_running(node_id)
-
         resp = self.api_client.is_running_api_v2_instances_instance_id_is_running_get(
             node_id
         )
         return resp.result.is_running
 
     def is_terminated(self, node_id: str) -> Any:
-        if not self.is_provider_supported:
-            return self.inner_provider.is_terminated(node_id)
-
         resp = self.api_client.is_terminated_api_v2_instances_instance_id_is_terminated_get(
             node_id
         )
         return resp.result.is_terminated
 
     def node_tags(self, node_id: str) -> Any:
-        if not self.is_provider_supported:
-            return self.inner_provider.node_tags(node_id)
-
         resp = self.api_client.get_instance_api_v2_instances_instance_id_get(node_id)
         return resp.result.tags
 
     def external_ip(self, node_id: str) -> Any:
-        if not self.is_provider_supported:
-            return self.inner_provider.external_ip(node_id)
-
         resp = self.api_client.external_ip_api_v2_instances_instance_id_external_ip_get(
             node_id
         )
         return resp.result.external_ip
 
     def internal_ip(self, node_id: str) -> Any:
-        if not self.is_provider_supported:
-            return self.inner_provider.internal_ip(node_id)
-
         resp = self.api_client.internal_ip_api_v2_instances_instance_id_internal_ip_get(
             node_id
         )
@@ -244,13 +212,9 @@ class AnyscaleInstanceManagerNodeProvider:
     def create_node(
         self, node_config: Dict[str, Any], tags: Dict[str, str], count: int
     ) -> None:
-        if not self.is_provider_supported:
-            self.inner_provider.create_node(node_config, tags, count)
-            return
-
         create_node_request = CreateNodesOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             node_config=node_config,
             tags=tags,
             count=count,
@@ -264,13 +228,9 @@ class AnyscaleInstanceManagerNodeProvider:
             raise RuntimeError(exception_message)
 
     def set_node_tags(self, node_id: str, tags: Dict[str, str]) -> None:
-        if not self.is_provider_supported:
-            self.inner_provider.set_node_tags(node_id, tags)
-            return
-
         set_node_tags_request = SetNodeTagsOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             instance_id=node_id,
             tags=tags,
         )
@@ -280,13 +240,9 @@ class AnyscaleInstanceManagerNodeProvider:
         )
 
     def terminate_node(self, node_id: str) -> None:
-        if not self.is_provider_supported:
-            self.inner_provider.terminate_node(node_id)
-            return
-
         terminate_nodes_request = NodesOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             instance_ids=[node_id],
         )
         self.api_client.terminate_nodes_api_v2_instances_terminate_nodes_post(
@@ -294,13 +250,9 @@ class AnyscaleInstanceManagerNodeProvider:
         )
 
     def terminate_nodes(self, node_ids: List[str]) -> None:
-        if not self.is_provider_supported:
-            self.inner_provider.terminate_nodes(node_ids)
-            return
-
         terminate_nodes_request = NodesOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             instance_ids=node_ids,
         )
         self.api_client.terminate_nodes_api_v2_instances_terminate_nodes_post(
@@ -316,13 +268,9 @@ class AnyscaleInstanceManagerNodeProvider:
         )
 
     def start_nodes(self, node_ids: List[str]) -> None:
-        if not self.is_provider_supported:
-            self.inner_provider.start_nodes(node_ids)
-            return
-
         start_nodes_request = NodesOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             instance_ids=node_ids,
         )
         self.api_client.start_nodes_api_v2_instances_start_nodes_post(
@@ -330,13 +278,9 @@ class AnyscaleInstanceManagerNodeProvider:
         )
 
     def stop_nodes(self, node_ids: List[str]) -> None:
-        if not self.is_provider_supported:
-            self.inner_provider.stop_nodes(node_ids)
-            return
-
         stop_nodes_request = NodesOptions(
-            provider_config=self.inner_provider.provider_config,
-            cluster_name=self.inner_provider.cluster_name,
+            provider_config=self.inner_provider_config,
+            cluster_name=self.cluster_name,
             instance_ids=node_ids,
         )
         self.api_client.stop_nodes_api_v2_instances_stop_nodes_post(stop_nodes_request)
@@ -344,11 +288,6 @@ class AnyscaleInstanceManagerNodeProvider:
     def get_node_id(
         self, ip_address: str, use_internal_ip: bool = False
     ) -> Optional[str]:
-        if not self.is_provider_supported:
-            return cast(
-                str, self.inner_provider.get_node_id(ip_address, use_internal_ip)
-            )
-
         if use_internal_ip:
             resp = self.api_client.get_node_id_by_internal_ip_api_v2_instances_internal_ip_get_node_id_by_internal_ip_get(
                 ip_address
