@@ -164,11 +164,11 @@ ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN = {
     ],
 }
 
-# Used for optional readonly access to SSM
+# Used for experimental readonly access to SSM
 ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT = {
     "Version": "2012-10-17",
     "Statement": {
-        "Sid": "1",
+        "Sid": "SecretsManagerReadOnly",
         "Effect": "Allow",
         "Action": [
             "secretsmanager:GetSecretValue",
@@ -178,3 +178,20 @@ ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT = {
         "Resource": "*",
     },
 }
+
+# Used for experimental read and write access to SSM
+ANYSCALE_SSM_READ_WRITE_ACCESS_POLICY_DOCUMENT = {
+    "Version": "2012-10-17",
+    "Statement": {
+        "Sid": "SecretsManagerReadWrite",
+        "Effect": "Allow",
+        "Action": [
+            "secretsmanager:CreateSecret",
+            "secretsmanager:PutSecretValue",
+            "secretsmanager:GetSecretValue",
+            "secretsmanager:DescribeSecret",
+            "secretsmanager:ListSecrets",
+        ],
+        "Resource": "*",
+    },
+}
