@@ -69,7 +69,7 @@ def cluster_cli() -> None:
     help=(
         "The YAML file of the cluster compute config to launch this cluster with. "
         "An example can be found at {website}. ".format(
-            website="https://docs.anyscale.com/user-guide/configure/compute-configs",
+            website="https://docs.anyscale.com/user-guide/configure/cluster-computes",
         )
     ),
 )
