@@ -1,4 +1,5 @@
-from typing import Optional
+import sys
+from typing import List, Optional
 
 import click
 
@@ -25,13 +26,31 @@ def service_cli() -> None:
 @click.option(
     "--description", required=False, default=None, help="Description of service."
 )
+@click.option(
+    "--healthcheck-url",
+    required=False,
+    default="/healthcheck",
+    help="Description of service.",
+)
+@click.argument(
+    "entrypoint", required=False, nargs=-1,
+)
 def deploy(
-    service_config_file: str, name: Optional[str], description: Optional[str],
+    service_config_file: str,
+    entrypoint: List[str],
+    name: Optional[str],
+    description: Optional[str],
+    healthcheck_url: Optional[str],
 ) -> None:
     # TODO[Bruce]: Remove update flag once fully test apply function.
     service_controller = ServiceController()
     service_controller.deploy(
-        service_config_file, name=name, description=description,
+        service_config_file,
+        name=name,
+        description=description,
+        healthcheck_url=healthcheck_url,
+        entrypoint=entrypoint,
+        is_entrypoint_cmd="--" in sys.argv,
     )
 
 
@@ -51,6 +70,15 @@ def deploy(
     default=False,
     help="Include services not created by current user.",
 )
+@click.option(
+    "--include-archived",
+    is_flag=True,
+    default=False,
+    help=(
+        "List archived services as well as unarchived services."
+        "If not provided, defaults to listing only unarchived services."
+    ),
+)
 @click.option(
     "--max-items",
     required=False,
@@ -64,6 +92,7 @@ def list(
     service_id: Optional[str],
     project_id: Optional[str],
     include_all_users: bool,
+    include_archived: bool,
     max_items: int,
 ) -> None:
     service_controller = ServiceController()
@@ -72,10 +101,19 @@ def list(
         service_id=service_id,
         project_id=project_id,
         include_all_users=include_all_users,
+        include_archived=include_archived,
         max_items=max_items,
     )
 
 
+@service_cli.command(name="archive", help="Archive a service.")
+@click.option("--service-id", "--id", required=False, help="Id of service.")
+@click.option("--name", "-n", required=False, help="Name of service.")
+def archive(service_id: Optional[str], name: Optional[str]) -> None:
+    service_controller = ServiceController()
+    service_controller.archive(service_id=service_id, service_name=name)
+
+
 @service_cli.command(
     name="terminate", help="Attempt to terminate a service asynchronously."
 )
