@@ -18,6 +18,7 @@ from anyscale.project import (
     get_proj_name_from_id,
     write_project_file_to_disk,
 )
+from anyscale.shared_anyscale_utils.utils.byod import BYODInfo
 from anyscale.util import get_endpoint
 
 
@@ -43,11 +44,54 @@ def workspace_cli() -> None:
     "--name", "-n", required=True, help="Name of the workspace to create.",
 )
 @click.option("--cloud-id", required=True)
-@click.option("--cluster-env-build-id", required=True)
+@click.option("--cluster-env-build-id", required=False)
+@click.option(
+    "--docker", required=False, default=None, help=("Custom docker image URI."),
+)
+@click.option(
+    "--python-version",
+    required=False,
+    default=None,
+    help=("Python version for the custom docker image."),
+)
+@click.option(
+    "--ray-version",
+    required=False,
+    default=None,
+    help=("Ray version for the custom docker image."),
+)
 @click.option("--compute-config-id", required=True)
 def create(
-    name: str, cloud_id: str, cluster_env_build_id: str, compute_config_id: str,
+    name: str,
+    cloud_id: str,
+    cluster_env_build_id: str,
+    docker: str,
+    python_version: str,
+    ray_version: str,
+    compute_config_id: str,
 ) -> None:
+    if cluster_env_build_id is None and docker is None:
+        raise click.ClickException(
+            "Please specify one of `--docker` or `--cluster-env-build-id`."
+        )
+    if docker is not None:
+        if cluster_env_build_id is not None:
+            raise click.ClickException(
+                "`--cluster-env-build-id` and `--docker` cannot both be "
+                "specified. Please only provide one of these two arguments."
+            )
+
+        if python_version is None:
+            raise click.ClickException(
+                "`--python-version` should be specified when `--docker` is used."
+            )
+        if ray_version is None:
+            raise click.ClickException(
+                "`--ray-version` should be specified when `--docker` is used."
+            )
+        # Create docker build_id
+        cluster_env_build_id = BYODInfo(docker, python_version, ray_version).encode()
+
     auth_api_client = get_auth_api_client()
     api_client = auth_api_client.api_client
     api_client.create_workspace_api_v2_experimental_workspaces_post(
