@@ -21,6 +21,7 @@ from anyscale.sdk.anyscale_client import (
     UpdateCluster,
 )
 from anyscale.sdk.anyscale_client.models.cloud import Cloud
+from anyscale.sdk.anyscale_client.models.compute_template import ComputeTemplate
 from anyscale.util import generate_slug, get_endpoint, wait_for_session_start
 from anyscale.utils.connect_helpers import get_cluster, list_entities
 
@@ -106,17 +107,15 @@ class PrepareClusterBlock:
         self.block_label = "PrepareCluster"
         self.log.open_block(self.block_label, block_title="Preparing the cluster")
 
-        needs_start = self._check_if_cluster_needs_start(
+        needs_start_or_create = self._check_if_cluster_needs_start_or_create(
             self.project_id, self.cluster_name, self.needs_update
         )
-        if needs_start:
-            existing_terminated_cluster = (
-                None
-                if self.cluster_name is None
-                else get_cluster(
+        if needs_start_or_create:
+            existing_terminated_cluster = None
+            if self.cluster_name:
+                existing_terminated_cluster = get_cluster(
                     self.anyscale_api_client, project_id, self.cluster_name
                 )
-            )
 
             self.cluster_env_name = self._build_cluster_env_if_needed(
                 project_id,
@@ -176,7 +175,7 @@ class PrepareClusterBlock:
 
             self._wait_for_app_build(project_id, build_id)
 
-            self.cluster_name = self._create_cluster(
+            self.cluster_name = self._start_or_create_cluster(
                 project_id=self.project_id,
                 build_id=build_id,
                 compute_template_id=compute_template_id,
@@ -187,13 +186,13 @@ class PrepareClusterBlock:
         else:
             assert (
                 self.cluster_name
-            ), f"{self.cluster_name} is None, yet _check_if_cluster_needs_start returned False."
+            ), f"{self.cluster_name} is None, yet _check_if_cluster_needs_start_or_create returned False."
             cluster = get_cluster(
                 self.anyscale_api_client, self.project_id, self.cluster_name
             )
             assert (
                 cluster
-            ), f"Cluster {self.cluster_name} not found, yet _check_if_cluster_needs_start returned False."
+            ), f"Cluster {self.cluster_name} not found, yet _check_if_cluster_needs_start_or_create returned False."
             self._validate_new_cluster_compute_and_env_match_existing_cluster(
                 project_id=self.project_id, running_cluster=cluster,
             )
@@ -204,12 +203,12 @@ class PrepareClusterBlock:
             self.log.info("Connecting to this cluster:", block_label=self.block_label)
             url = get_endpoint(f"/projects/{project_id}/clusters/{cluster.id}")
             self._log_cluster_configs(
-                cluster, cluster.build_id, cluster.compute_template_id, url
+                cluster, cluster.build_id, cluster.compute_template_id, url,
             )
 
         self.log.close_block(self.block_label)
 
-    def _create_cluster(  # noqa: C901
+    def _start_or_create_cluster(  # noqa: C901
         self,
         project_id: str,
         build_id: str,
@@ -234,11 +233,9 @@ class PrepareClusterBlock:
             The name of the cluster to connect to.
         """
         ray_cli = self._ray.util.client.ray
-        create_new_cluster = False
-        if not cluster_name:
-            # If a cluster name is not provided, user wants to start a new cluster.
-            create_new_cluster = True
-
+        # If a cluster name is not specified, user wants to start a new cluster.
+        did_user_not_specify_cluster_name = not cluster_name
+        if did_user_not_specify_cluster_name:
             # Try to generate an auto-incrementing cluster name from the first 100 clusters.
             # If there are more than 40 clusters with, we will generate a random name.
             # If the name is already taken, we will re-try with a different random name.
@@ -262,39 +259,7 @@ class PrepareClusterBlock:
             self._ray.util.disconnect()
         # Update cluster.
         self.log.debug("Starting cluster with sdk and compute config.")
-        return self._start_cluster(
-            project_id=project_id,
-            cluster_name=cluster_name,
-            build_id=build_id,
-            compute_template_id=compute_template_id,
-            autosuspend_timeout=autosuspend_timeout,
-            allow_public_internet_traffic=allow_public_internet_traffic,
-            create_new_cluster=create_new_cluster,
-        )
 
-    def _start_cluster(
-        self,
-        project_id: str,
-        cluster_name: Optional[str],
-        build_id: str,
-        compute_template_id: str,
-        autosuspend_timeout: int,
-        allow_public_internet_traffic: Optional[bool],
-        create_new_cluster: bool,
-    ) -> str:
-        """Create/update/start the cluster if required.
-
-        Args:
-            project_id (str): The project to use.
-            build_id (str): Build to start cluster with.
-            compute_template_id (str): Compute template to start cluster with
-            cluster_name (Optional[str]): If specified, the given cluster
-                will be created or updated as needed. Otherwise the cluster
-                name will be picked automatically.
-            autosuspend_timeout (int): Autosuspend value of cluster
-            allow_public_internet_traffic (bool): Whether to allow public internet
-                traffic to serve endpoints
-        """
         cluster, start_required = self._create_or_update_session_data(
             cluster_name,
             project_id,
@@ -302,9 +267,37 @@ class PrepareClusterBlock:
             compute_template_id,
             autosuspend_timeout,
             bool(allow_public_internet_traffic),
-            create_new_cluster=create_new_cluster,
+            did_user_not_specify_cluster_name,
+        )
+        return self._start_cluster_if_required(
+            cluster,
+            start_required,
+            project_id,
+            build_id,
+            compute_template_id,
+            allow_public_internet_traffic,
         )
 
+    def _start_cluster_if_required(
+        self,
+        cluster: Session,
+        start_required: bool,
+        project_id: str,
+        build_id: str,
+        compute_template_id: str,
+        allow_public_internet_traffic: Optional[bool],
+    ) -> str:
+        """Start the cluster if required.
+
+        Args:
+            cluster (Session): The cluster to start.
+            start_required (bool): Whether the cluster.
+            project_id (str): The project to use.
+            build_id (str): Build to start cluster with.
+            compute_template_id (str): Compute template to start cluster with
+            allow_public_internet_traffic (bool): Whether to allow public internet
+                traffic to serve endpoints
+        """
         url = get_endpoint(f"/projects/{project_id}/clusters/{cluster.id}")
 
         if start_required:
@@ -312,7 +305,10 @@ class PrepareClusterBlock:
                 "Note that restarting the cluster will not change the configurations correctly "
                 "in AIOA or GCP."
             )
-            self._log_cluster_configs(cluster, build_id, compute_template_id, url)
+
+        self._log_cluster_configs(cluster, build_id, compute_template_id, url)
+
+        if start_required:
             self.anyscale_api_client.start_cluster(
                 cluster.id,
                 StartClusterOptions(
@@ -330,13 +326,11 @@ class PrepareClusterBlock:
                 block_label=self.block_label,
             )
             self.log.debug(f"Cluster {cluster.name} finished starting. View at {url}")
-        else:
-            self._log_cluster_configs(cluster, build_id, compute_template_id, url)
 
         return str(cluster.name)
 
     def _log_cluster_configs(
-        self, cluster: Session, build_id: str, compute_template_id: str, url: str
+        self, cluster: Session, build_id: str, compute_template_id: str, url: str,
     ) -> None:
         """Prints information about the cluster."""
 
@@ -346,9 +340,11 @@ class PrepareClusterBlock:
             cluster_env.application_template_id + ":" + str(cluster_env.revision)
         )
 
-        cluster_compute_name = self.anyscale_api_client.get_compute_template(
+        compute_config: ComputeTemplate = self.anyscale_api_client.get_compute_template(
             compute_template_id
-        ).result.name
+        ).result
+        compute_config_name = compute_config.name
+        compute_config_config = compute_config.config
 
         left_pad = " " * 2
         self.log.info(
@@ -363,13 +359,28 @@ class PrepareClusterBlock:
             block_label=self.block_label,
         )
         self.log.info(
-            f"{left_pad}{'cluster compute:': <30}{cluster_compute_name}",
+            f"{left_pad}{'cluster compute:': <30}{compute_config_name}",
             block_label=self.block_label,
         )
         self.log.info(
             f"{left_pad}{'cluster compute id:': <30}{compute_template_id}",
             block_label=self.block_label,
         )
+
+        def get_minutes_output(field: Optional[int]) -> str:
+            if field and field > 0:
+                return f"{field} minutes"
+            return "disabled"
+
+        self.log.info(
+            f"{left_pad}{'idle termination:': <30}{get_minutes_output(cluster.idle_timeout)}",
+            block_label=self.block_label,
+        )
+        self.log.info(
+            f"{left_pad}{'maximum uptime:': <30}{get_minutes_output(compute_config_config.maximum_uptime_minutes)}",
+            block_label=self.block_label,
+        )
+
         self.log.info(f"{left_pad}{'link:': <30}{url}", block_label=self.block_label)
 
     def _create_or_update_session_data(
@@ -380,7 +391,7 @@ class PrepareClusterBlock:
         compute_template_id: str,
         idle_timeout: Optional[int],
         allow_public_internet_traffic: bool = False,
-        create_new_cluster: bool = False,
+        did_user_not_specify_cluster_name: bool = False,
     ) -> Tuple[Session, bool]:
         """
         If cluster name is None, creates a new cluster with a generates a cluster name.
@@ -398,7 +409,7 @@ class PrepareClusterBlock:
 
         cluster = get_cluster(self.anyscale_api_client, project_id, cluster_name)
 
-        if create_new_cluster:
+        if did_user_not_specify_cluster_name:
             while cluster:
                 # User wants to create a new cluster but cluster with name already exists,
                 # generate a new name until we have one that's not taken.
@@ -409,6 +420,8 @@ class PrepareClusterBlock:
 
         if not cluster:
             # Create a new cluster if there is no existing cluster with the given cluster_name
+            # This will occur if the user did not specify a cluster name, or if a cluster with
+            # the user specified cluster_name does not exist.
             self.log.info(
                 f"Cluster {BlockLogger.highlight(cluster_name)} does not exist. A new cluster will be created.",
                 block_label=self.block_label,
@@ -425,9 +438,9 @@ class PrepareClusterBlock:
                 idle_timeout_minutes=idle_timeout,
                 allow_public_internet_traffic=allow_public_internet_traffic,
             )
-            cluster = self.anyscale_api_client.create_cluster(
-                create_cluster_data
-            ).result
+            self.anyscale_api_client.create_cluster(create_cluster_data)
+            cluster = get_cluster(self.anyscale_api_client, project_id, cluster_name)
+            assert cluster is not None
         else:
             # Get the existing cluster and update the idle_timeout if required
             if cluster.state == "Running":
@@ -469,10 +482,10 @@ class PrepareClusterBlock:
 
         return cluster, start_required
 
-    def _check_if_cluster_needs_start(
+    def _check_if_cluster_needs_start_or_create(
         self, project_id: str, cluster_name: Optional[str], needs_update: bool
     ):
-        """Returns True if the cluster needs to be started/update or else returns False.
+        """Returns True if the cluster needs to be started/updated/created or else returns False.
         Returns False only when the cluster is currently running and the user did not
         explicitly pass an update request (`.cluster_env(..., update=True)`).
         """
@@ -480,16 +493,16 @@ class PrepareClusterBlock:
             cluster = get_cluster(self.anyscale_api_client, project_id, cluster_name)
             if not cluster:
                 # Unconditionally create the cluster if it isn't up.
-                needs_start = True
+                needs_start_or_create = True
             elif cluster.state != "Running":
                 # Unconditionally create the cluster if it isn't up.
-                needs_start = True
+                needs_start_or_create = True
             else:
-                needs_start = needs_update
+                needs_start_or_create = needs_update
         else:
-            needs_start = True
+            needs_start_or_create = True
 
-        return needs_start
+        return needs_start_or_create
 
     def _get_default_cluster_env_build(self) -> Build:
         """
