@@ -16,6 +16,7 @@ from anyscale.aws_iam_policies import (
     AMAZON_S3_FULL_ACCESS_POLICY_ARN,
     ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN,
     ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
+    ANYSCALE_SSM_READ_WRITE_ACCESS_POLICY_DOCUMENT,
     ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT,
 )
 from anyscale.cli_logger import BlockLogger
@@ -156,6 +157,7 @@ class CloudController(BaseController):
         region: Optional[str],
         name: str,
         yes: bool = False,
+        gce: bool = False,
         folder_id: Optional[int] = None,
         vpc_peering_ip_range: Optional[str] = None,
         vpc_peering_target_project_id: Optional[str] = None,
@@ -211,6 +213,7 @@ class CloudController(BaseController):
             launch_gcp_cloud_setup(
                 name=name,
                 region=region,
+                is_k8s=not gce,
                 folder_id=folder_id,
                 vpc_peering_ip_range=vpc_peering_ip_range,
                 vpc_peering_target_project_id=vpc_peering_target_project_id,
@@ -251,7 +254,7 @@ class CloudController(BaseController):
         anyscale_aws_iam_role_policy: Dict[str, Any] = {
             "Version": "2012-10-17",
             "Statement": {
-                "Sid": "1",
+                "Sid": "AnyscaleControlPlaneAssumeRole",
                 "Effect": "Allow",
                 "Principal": {"AWS": anyscale_aws_account},
                 "Action": "sts:AssumeRole",
@@ -420,7 +423,11 @@ class CloudController(BaseController):
         self.log.info(f"Updated default cloud to {cloud_name}")
 
     def experimental_setup_secrets(
-        self, cloud_name: Optional[str], cloud_id: Optional[str], yes: bool = False
+        self,
+        cloud_name: Optional[str],
+        cloud_id: Optional[str],
+        write_permissions: bool,
+        yes: bool,
     ):
         """
         Given a cloud name, look up its provider and give it permissions to read secrets
@@ -430,8 +437,8 @@ class CloudController(BaseController):
         ).result.is_on
         if not feature_flag_on:
             raise ClickException(
-                "Secrets can only be set up if the wandb-integration-prototype feature "
-                "flag is serving True."
+                "Secrets can only be set up if the feature flag is enabled. "
+                "Please contact Anyscale support to enable the flag."
             )
 
         cloud_id, cloud_name = get_cloud_id_and_name(
@@ -444,7 +451,9 @@ class CloudController(BaseController):
         )
 
         if cloud.provider == "AWS":
-            return self._experimental_grant_secrets_access_aws(cloud, yes)
+            return self._experimental_grant_secrets_access_aws(
+                cloud, write_permissions, yes
+            )
 
         if cloud.provider == "GCP":
             raise ClickException(
@@ -453,10 +462,14 @@ class CloudController(BaseController):
 
         raise ClickException(f"Cloud secrets not supported for {cloud_name}")
 
-    def _experimental_grant_secrets_access_aws(self, cloud: Cloud, yes: bool) -> None:
+    def _experimental_grant_secrets_access_aws(
+        self, cloud: Cloud, write_permissions: bool, yes: bool
+    ) -> None:
         """Creates IAM policy for SSM readonly access and attaches it to the given role
         Args:
             cloud (Cloud): Cloud object which needs modification
+            write_permissions (bool): Whether to add write permissions for Secrets Manager
+                to policy
         """
 
         # Ensure they are in the correct AWS account, by checking account used
@@ -491,11 +504,18 @@ class CloudController(BaseController):
             role is not None
         ), f"Failed to find IAM role {role_name} in Cloud {cloud.name}! Have you run 'cloud setup'?"
 
-        policy_name = f"anyscale-secrets-readonly-{cloud.id}"
-
-        role.Policy(name=policy_name).put(
-            PolicyDocument=json.dumps(ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT),
+        policy_name = (
+            f"anyscale-secrets-read-write-{cloud.id}"
+            if write_permissions
+            else f"anyscale-secrets-readonly-{cloud.id}"
         )
+        policy_document = (
+            ANYSCALE_SSM_READ_WRITE_ACCESS_POLICY_DOCUMENT
+            if write_permissions
+            else ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT
+        )
+
+        role.Policy(name=policy_name).put(PolicyDocument=json.dumps(policy_document),)
         self.log.info(
             f"Successfully added/updated inline policy {policy_name} on role {role_name}."
         )
