@@ -384,7 +384,7 @@ class ClusterController(BaseController):
         else:
             project_id = get_and_validate_project_id(
                 project_id=project_id,
-                project_name=None,
+                project_name=project_name,
                 api_client=self.api_client,
                 anyscale_api_client=self.anyscale_api_client,
             )
