@@ -8,13 +8,12 @@ from typing import Any, List, Tuple
 import click
 
 import anyscale
-from anyscale.api import get_api_client
-from anyscale.cli_logger import _CliLogger
-from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models.execute_interactive_command_options import (
     ExecuteInteractiveCommandOptions,
 )
 from anyscale.cluster_config import get_cluster_config
+from anyscale.controllers.base_controller import BaseController
 from anyscale.project import get_project_id, get_project_session, load_project_or_throw
 import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
 from anyscale.shared_anyscale_utils.util import execution_log_name
@@ -31,13 +30,11 @@ def rsync(*args: Any, **kwargs: Any) -> None:
     ray_rsync(*args, **kwargs)
 
 
-class ExecController(object):
+class ExecController(BaseController):
     def __init__(
-        self, api_client: DefaultApi = None, log: _CliLogger = _CliLogger(),
+        self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
     ):
-        if api_client is None:
-            api_client = get_api_client()
-        self.api_client = api_client
+        super().__init__(initialize_auth_api_client=initialize_auth_api_client)
         self.log = log
 
     def anyscale_exec(
@@ -52,11 +49,10 @@ class ExecController(object):
         commands: List[str],
     ) -> None:
         message = (
-            "Warning: `anyscale exec` is not recommended for sessions started with "
-            "ray.client().connect(). Please call your script from a subprocess call in a remote "
-            "function for ray.client().connect() sessions."
+            "Warning: `anyscale exec` has been deprecated. Please use `anyscale job submit` "
+            "to run your script as a job in a cluster."
         )
-        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
+        self.log.warning(message)
         import ray.scripts.scripts as autoscaler_scripts
 
         if screen and tmux:
