@@ -18,11 +18,13 @@ import yaml
 
 from anyscale.cli_logger import LogsLogger
 from anyscale.client.openapi_client import (
+    ComputeTemplate,
     CreateCronJob,
     CreateProductionJob,
     DecoratedProductionJob,
     HaJobStates,
     JobsLogsQueryInfo,
+    ProductionJob,
     ProductionJobConfig,
 )
 from anyscale.cluster_compute import (
@@ -592,6 +594,9 @@ class JobController(BaseController):
                 config=config_object,
             )
         ).result
+        self.log.info(
+            f"Maximum uptime is {self._get_maximum_uptime_output(job)} for clusters launched by this job."
+        )
         self.log.info(
             f"Job {job.id} has been successfully submitted. Current state of job: {job.state.current_state}."
         )
@@ -604,6 +609,15 @@ class JobController(BaseController):
         self.log.info(f'View the job in the UI at {get_endpoint(f"/jobs/{job.id}")}.')
         return job.id
 
+    def _get_maximum_uptime_output(self, job: ProductionJob) -> str:
+        compute_config: ComputeTemplate = self.api_client.get_compute_template_api_v2_compute_templates_template_id_get(
+            job.config.compute_config_id
+        ).result
+        maximum_uptime_minutes = compute_config.config.maximum_uptime_minutes
+        if maximum_uptime_minutes and maximum_uptime_minutes > 0:
+            return f"set to {maximum_uptime_minutes} minutes"
+        return "disabled"
+
     def schedule(
         self,
         job_config_file: str,
