@@ -8,7 +8,12 @@ from pydantic import Field
 import yaml
 
 from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client import CreateProductionService, ProductionJobConfig
+from anyscale.client.openapi_client import (
+    ComputeTemplate,
+    CreateProductionService,
+    ProductionJob,
+    ProductionJobConfig,
+)
 from anyscale.controllers.base_controller import BaseController
 from anyscale.controllers.job_controller import JobConfig, JobController
 from anyscale.project import infer_project_id
@@ -144,6 +149,11 @@ class ServiceController(BaseController):
             )
         ).result
 
+        maximum_uptime_minutes = self._get_maximum_uptime_minutes(service)
+        self.log.info(
+            f"Maximum uptime is {self._get_maximum_uptime_output(maximum_uptime_minutes)} for clusters launched by this service."
+            f"{self._get_additional_log_if_maximum_uptime_enabled(maximum_uptime_minutes)}"
+        )
         self.log.info(
             f"Service {service.id} has been deployed. Current state of service: {service.state.current_state}."
         )
@@ -154,6 +164,24 @@ class ServiceController(BaseController):
             f'View the service in the UI at {get_endpoint(f"/services/{service.id}")}.'
         )
 
+    def _get_maximum_uptime_minutes(self, service: ProductionJob) -> Optional[int]:
+        compute_config: ComputeTemplate = self.api_client.get_compute_template_api_v2_compute_templates_template_id_get(
+            service.config.compute_config_id
+        ).result
+        return compute_config.config.maximum_uptime_minutes
+
+    def _get_maximum_uptime_output(self, maximum_uptime_minutes: Optional[int]) -> str:
+        if maximum_uptime_minutes and maximum_uptime_minutes > 0:
+            return f"set to {maximum_uptime_minutes} minutes"
+        return "disabled"
+
+    def _get_additional_log_if_maximum_uptime_enabled(
+        self, maximum_uptime_minutes: Optional[int]
+    ) -> str:
+        if maximum_uptime_minutes and maximum_uptime_minutes > 0:
+            return " This may cause disruptions. To disable, update the compute config."
+        return ""
+
     def _populate_service_config(self, config_dict: Dict[str, Any]) -> ServiceConfig:
         if "ANYSCALE_EXPERIMENTAL_WORKSPACE_ID" in os.environ:
             if "ANYSCALE_SESSION_ID" in os.environ:
