@@ -1,4 +1,5 @@
-from datetime import datetime
+import asyncio
+from datetime import datetime, timedelta
 import json
 import os
 from os import path
@@ -7,7 +8,9 @@ import subprocess
 import sys
 from typing import Any, Dict, List, Optional, Sequence, Union
 
+import aiohttp
 import click
+from tqdm import tqdm
 import yaml
 
 from anyscale.cli_logger import BlockLogger
@@ -21,6 +24,14 @@ from anyscale.client.openapi_client import (
     SetupInitializeSessionOptions,
     StopSessionOptions,
 )
+from anyscale.client.openapi_client.models import (
+    LogDetail,
+    LogDetails,
+    LogDownloadConfig,
+    LogDownloadRequest,
+    LogFilter,
+    NodeType,
+)
 from anyscale.cloud import get_cloud_id_and_name
 from anyscale.cluster_config import (  # pylint:disable=private-import
     _configure_min_max_workers,
@@ -830,3 +841,179 @@ class SessionController(BaseController):
             )
 
         return sessions_list[0]
+
+    def download_log_files(
+        self,
+        base_folder: Optional[str] = None,
+        glob: Optional[str] = None,
+        session_id: Optional[str] = None,
+        node_id: Optional[str] = None,
+        job_id: Optional[str] = None,
+        job_run: Optional[str] = None,
+        node_type: Optional[NodeType] = None,
+        page_size: Optional[int] = None,
+        ttl_seconds: Optional[int] = None,
+        parallelism: int = 10,
+        read_timeout: timedelta = timedelta(minutes=30),
+    ) -> None:
+        """Download all log files based on the passed parameters, by repeatedly calling get_log_files_api_v2,
+        with each call returning a *page_size* of results.
+
+        Parameters
+        ----------
+        base_folder: Optional[str]
+            Base folder to download files into. If not provided, then logs will be downloaded in the current working directory.
+        glob: Optional[str]
+            Glob expression to filter logs.
+        session_id: Optional[str]
+            DB id of the session.
+        node_id: Optional[str]
+            Id of a node, usually a worker node.
+        job_id: Optional[str]
+            the job id for which the logs should be retrieved.
+        job_run: Optional[str]
+            the job run name for which the logs should be retrieved.
+        node_type: Optional[NodeType]
+            either head-node or worker-nodes
+        page_size: Optional[int]
+            Max number of files to fetch at a time from the API.
+        ttl_seconds: Optional[int]
+            TTL of the presigned URL for downloading logs.
+        parallelism: int
+            Number of log files to download in parallel at a time.
+        read_timeout: timedelta
+            The read timeout while downloading log file.
+        """
+        next_page_token: Optional[str] = None
+        while True:
+            log_details: LogDetails = self.api_client.get_log_files_api_v2_sessions_session_id_get_log_files_post(
+                session_id or "latest",
+                log_download_request=LogDownloadRequest(
+                    filter=LogFilter(
+                        glob=glob,
+                        node_id=node_id,
+                        job_id=job_id,
+                        job_run=job_run,
+                        node_type=node_type,
+                    ),
+                    config=LogDownloadConfig(
+                        next_page_token=next_page_token,
+                        page_size=page_size,
+                        ttl_seconds=ttl_seconds,
+                    ),
+                ),
+            ).result
+            log_files: List[LogDetail] = log_details.log_files
+            asyncio.run(
+                self._download_files(base_folder, log_files, parallelism, read_timeout)
+            )
+            if log_details.next_page_token is None:
+                break
+            next_page_token = log_details.next_page_token
+
+    def download_ray_result_files(
+        self,
+        base_folder: Optional[str] = None,
+        session_id: Optional[str] = None,
+        job_id: Optional[str] = None,
+        job_run: Optional[str] = None,
+        parallelism: int = 10,
+        read_timeout: timedelta = timedelta(minutes=30),
+    ) -> None:
+        """Download ray tune result files based on the passed parameters.
+
+        Parameters
+        ----------
+        base_folder: Optional[str]
+            Base folder to download files into. If not provided, then results will be downloaded in the current working directory.
+        session_id: Optional[str]
+            DB id of the session.
+        job_id: Optional[str]
+            the job id for which the results should be retrieved.
+        job_run: Optional[str]
+            the job run name for which the results should be retrieved.
+        parallelism: int
+            Number of result files to download in parallel at a time.
+        read_timeout: timedelta
+            The read timeout while downloading result file.
+        """
+        log_details: LogDetails = self.api_client.get_ray_result_files_api_v2_sessions_session_id_get_ray_result_files_get(
+            session_id or "latest", job_id=job_id, job_run=job_run,
+        ).result
+        log_files: List[LogDetail] = log_details.log_files
+        asyncio.run(
+            self._download_files(base_folder, log_files, parallelism, read_timeout)
+        )
+
+    async def _download_file(
+        self,
+        sem: asyncio.Semaphore,
+        pos: int,
+        file_name: str,
+        url: str,
+        size: int,
+        session: aiohttp.ClientSession,
+        read_timeout: timedelta,
+    ) -> None:
+        try:
+            async with sem:
+                download_dir = os.path.dirname(file_name)
+                if download_dir and not os.path.exists(download_dir):
+                    os.makedirs(download_dir)
+
+                timeout = aiohttp.ClientTimeout(
+                    total=None, sock_connect=30, sock_read=read_timeout.seconds
+                )
+                async with session.get(url, timeout=timeout) as response:
+                    if response.status == 200:
+                        pbar = tqdm(
+                            total=int(size),
+                            unit="iB",
+                            unit_scale=True,
+                            unit_divisor=1024,
+                            desc=file_name,
+                            leave=False,
+                            colour="green",
+                            position=pos,
+                        )
+                        with open(file_name, "wb") as fhand:
+                            async for chunk in response.content.iter_chunked(1024):
+                                fhand.write(chunk)
+                                pbar.update(len(chunk))
+                        pbar.close()
+                    else:
+                        self.log.error(
+                            f"Unable to download file {file_name}! response: [{response.status}, {await response.text()}]"
+                        )
+        except BaseException as e:
+            self.log.error(f"Error downloading file {file_name}: {e}")
+
+    async def _download_files(
+        self,
+        base_folder: Optional[str],
+        log_files: List[LogDetail],
+        parallelism: int,
+        read_timeout: timedelta,
+    ) -> None:
+        sem = asyncio.Semaphore(parallelism)
+        downloads = []
+        connector = aiohttp.TCPConnector(limit_per_host=parallelism)
+        async with aiohttp.ClientSession(connector=connector) as session:
+            for pos, log_detail in enumerate(log_files):
+                downloads.append(
+                    asyncio.create_task(
+                        self._download_file(
+                            sem,
+                            pos,
+                            os.path.join(
+                                base_folder or "", log_detail.name.lstrip("/")
+                            ),
+                            log_detail.download_url,
+                            log_detail.size,
+                            session,
+                            read_timeout,
+                        )
+                    )
+                )
+
+            await asyncio.gather(*downloads)
