@@ -6,7 +6,7 @@ from typing import List
 
 import tabulate
 
-from anyscale.client.openapi_client.models.cloud import Cloud  # type: ignore
+from anyscale.client.openapi_client.models.cloud import Cloud
 
 
 def format_clouds_output(clouds: List[Cloud], json_format: bool) -> str:
