@@ -14,6 +14,7 @@ from anyscale.commands.cluster_commands import cluster_cli
 from anyscale.commands.cluster_compute_commands import cluster_compute_cli
 from anyscale.commands.cluster_env_commands import cluster_env_cli
 from anyscale.commands.config_commands import config_cli
+from anyscale.commands.download_logs_commands import log_cli
 from anyscale.commands.exec_commands import anyscale_exec
 from anyscale.commands.experimental_integrations_commands import (
     experimental_integrations_cli,
@@ -139,6 +140,8 @@ cli.add_command(cluster_compute_cli)
 # Commands to interact with the Anyscale API
 cli.add_command(anyscale_api)
 
+cli.add_command(log_cli)
+
 ALIASES = {"h": anyscale_help}
 
 
