@@ -3,6 +3,8 @@ from time import sleep, time
 from typing import Any, Dict, Optional
 
 from anyscale.api import configure_tcp_keepalive
+from anyscale.sdk.anyscale_client.models.cluster_compute_config import ClusterComputeConfig
+from anyscale.sdk.anyscale_client.models.create_cluster_compute import CreateClusterCompute
 from anyscale.utils.runtime_env import upload_and_rewrite_working_dir
 import anyscale.sdk.anyscale_client as anyscale_client
 from anyscale.sdk.anyscale_client.api.default_api import DefaultApi
@@ -18,7 +20,7 @@ from anyscale.shared_anyscale_utils.headers import RequestHeaders
 from anyscale.cli_logger import BlockLogger
 from anyscale.util import get_endpoint
 from anyscale.authenticate import AuthenticationBlock
-
+from anyscale_client.models import ClusterEnvironmentBuildStatus
 
 def _upload_and_rewrite_working_dir_in_create_production_job(create_production_job):
     if create_production_job.config is not None:
@@ -27,6 +29,8 @@ def _upload_and_rewrite_working_dir_in_create_production_job(create_production_j
             new_runtime_env = upload_and_rewrite_working_dir(runtime_env)
             create_production_job.config["runtime_env"] = new_runtime_env
 
+# Build states that are in progress
+IN_PROGRESS_BUILD_STATES = [ClusterEnvironmentBuildStatus.IN_PROGRESS, ClusterEnvironmentBuildStatus.PENDING]
 
 class AnyscaleSDK(DefaultApi):  # type: ignore
     def __init__(
@@ -48,6 +52,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         configure_tcp_keepalive(api_client)
         api_client.set_default_header(RequestHeaders.CLIENT, "SDK")
         api_client.set_default_header(RequestHeaders.CLIENT_VERSION, version)
+
         self.log: BlockLogger = BlockLogger()
 
         super(AnyscaleSDK, self).__init__(api_client)
@@ -138,32 +143,33 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         self.log.log_output = log_output
         timeout = time() + timeout_seconds if timeout_seconds else None
 
-        operation = self.get_cluster_environment_build_operation(operation_id).result
+        operation = self.get_build(operation_id)
         url = get_endpoint(
-            f"configurations/app-config-details/{operation.cluster_environment_build_id}"
+            f"configurations/app-config-details/{operation_id}"
         )
         self.log.info(
             f"Waiting for cluster environment to build. View progress at {url}."
         )
-        while not operation.completed:
+        self.log.info(f"status: {operation.result.status}")
+        while operation.result.status in IN_PROGRESS_BUILD_STATES:
             if timeout and time() > timeout:
                 raise Exception(
                     f"Building Cluster Environment timed out after {timeout_seconds} seconds."
                 )
 
             sleep(poll_rate_seconds)
-            operation = self.get_cluster_environment_build_operation(
+            self.log.info(f"status: {operation.result.status}")
+            operation = self.get_build(
                 operation_id
-            ).result
-
-        if operation.result.error:
+            )
+        if operation.result.status != ClusterEnvironmentBuildStatus.SUCCEEDED:
             raise Exception(
-                "Failed to build Cluster Environment", operation.result.error
+                f"Failed to build Cluster Environment, you can check the full logs at: {url}."
             )
         else:
             self.log.info("Cluster environment successfully finished building.")
-            return self.get_cluster_environment_build(
-                operation.cluster_environment_build_id
+            return self.get_build(
+                operation_id
             ).result
 
     def launch_cluster(
@@ -175,6 +181,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         poll_rate_seconds: int = 15,
         timeout_seconds: Optional[int] = None,
         idle_timeout_minutes: Optional[int] = None,
+        cluster_compute_config: Optional[ClusterComputeConfig] = None,
     ) -> Cluster:
         """
         Starts a Cluster in the specified Project.
@@ -187,10 +194,12 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             cluster_environment_build_id - Cluster Environment Build to start this Cluster with
                                            If none, uses a default cluster_environment_build
             cluster_compute_id - Cluster Compute to start this Cluster with
-                                 If none, uses a default cluster_compute
+                                 If none, it checks if `cluster_compute_config` is specified. 
+                                 If `cluster_compute_config` is none, it uses a default cluster_compute.
             poll_rate_seconds - seconds to wait when polling Cluster operation status; defaults to 15
             timeout_seconds - maximum number of seconds to wait for Cluster operation to complete before timing out; defaults to no timeout
             idle_timeout_minutes - Idle timeout (in minutes), after which the Cluster is terminated
+            cluster_compute_config - One-off Cluster Compute that this Cluster will use.
 
         Returns:
             Cluster object
@@ -234,8 +243,11 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                 ).result.id
 
             if not cluster_compute_id:
-                # Use default cluster compute when starting cluster without specifying an id
-                cluster_compute_id = self.get_default_cluster_compute().result.id
+                if cluster_compute_config:
+                    cluster_compute_id = self.create_cluster_compute(CreateClusterCompute(config=cluster_compute_config, anonymous=True)).result.id
+                else:
+                    # Use default cluster compute when starting cluster without specifying an id
+                    cluster_compute_id = self.get_default_cluster_compute().result.id
 
             create_cluster_payload: Dict[str, Any] = {
                 "name": cluster_name,
@@ -268,6 +280,8 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         cluster_compute_id: Optional[str] = None,
         poll_rate_seconds: int = 15,
         timeout_seconds: Optional[int] = None,
+        idle_timeout_minutes: Optional[int] = None,
+        cluster_compute_config: Optional[ClusterComputeConfig] = None,
     ) -> Cluster:
         """
         Builds a new Cluster Environment, then starts a Cluster in the specified Project with the new build.
@@ -279,8 +293,12 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             cluster_name - Name of the Cluster
             create_cluster_environment - CreateClusterEnvironment object
             cluster_compute_id - Cluster Compute to start this Cluster with
+                                 If none, it checks if `cluster_compute_config` is specified. 
+                                 If `cluster_compute_config` is  none, it uses a default cluster_compute.
             poll_rate_seconds - seconds to wait when polling for operations; defaults to 15
             timeout_seconds - maximum number of seconds to wait for each operation to complete before timing out; defaults to no timeout
+            idle_timeout_minutes - Idle timeout (in minutes), after which the Cluster is terminated
+            cluster_compute_config - One-off Cluster Compute that this Cluster will use.
 
         Returns:
             Cluster object
@@ -300,6 +318,8 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             cluster_compute_id,
             poll_rate_seconds,
             timeout_seconds,
+            idle_timeout_minutes,
+            cluster_compute_config,
         )
 
     def wait_for_cluster_operation(
@@ -370,7 +390,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
 
     def fetch_job_logs(self, job_id: str) -> str:
         """
-        Retrieves logs for a Job.
+        Retrieves logs for a Ray Job or Interactive Session.
         This function may take several minutes if the Cluster this Job ran on has been terminated.
 
         Args:
@@ -393,7 +413,59 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                 raise Exception(f"Failed to get logs from Job {job_id}")
 
             sleep(15)
-            logs = self.get_actor_logs(job_id).result
+            logs = self.get_job_logs(job_id).result
+
+        return str(logs.logs)
+
+    def get_production_job_logs(self, job_id: str) -> str:
+        """
+        Retrieves logs for latest run of a Production Job.
+
+        Args:
+            job_id - ID of the Job
+
+        Returns
+            Log output for the Job as a string
+
+        Raises
+            Exception if we fail to fetch logs
+        """
+
+        latest_job_run_id = self.get_production_job(
+            production_job_id=job_id
+        ).result.last_job_run_id
+        if not latest_job_run_id:
+            raise Exception(f"Production Job {job_id} does not have a job run.")
+
+        return self.get_job_logs(latest_job_run_id)
+
+    def fetch_production_job_logs(self, job_id: str) -> str:
+        """
+        Retrieves logs for latest run of a Production Job.
+        Waits 5 min for logs to be ready.
+        This function may take several minutes if the Cluster this Job ran on has been terminated.
+
+        Args:
+            job_id - ID of the Job
+
+        Returns
+            Log output for the Job as a string
+
+        Raises
+            Exception if we fail to fetch logs
+        """
+
+        # Timeout in 5 minutes
+        timeout = time() + 300
+
+        logs = self.get_production_job_logs(job_id).result
+
+        while not logs.ready:
+            if time() > timeout:
+                raise Exception(f"Failed to get logs from Job {job_id}")
+
+            sleep(15)
+            logs = self.get_production_job_logs(job_id).result
 
         return str(logs.logs)
 
@@ -401,6 +473,18 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         _upload_and_rewrite_working_dir_in_create_production_job(create_production_job)
         return super().create_job(create_production_job, **kwargs)
 
+    def create_service(self, create_production_service, **kwargs):
+        _upload_and_rewrite_working_dir_in_create_production_job(
+            create_production_service
+        )
+        return super().create_service(create_production_service, **kwargs)
+
+    def apply_service(self, create_production_service, **kwargs):
+        _upload_and_rewrite_working_dir_in_create_production_job(
+            create_production_service
+        )
+        return super().apply_service(create_production_service, **kwargs)
+
     def get_cluster_token(self, project_id: str, cluster_name: str) -> str:
         """
         Retrieves cluster token for a Cluster.
