@@ -101,7 +101,9 @@ def create_snapshot_zip(directory: str, auto: bool) -> str:
 
     start = time.time()
     orig = os.path.abspath(os.curdir)
-    prefix = "snapshot_{}_".format(datetime.datetime.utcnow().isoformat())
+    prefix = "snapshot_{}_".format(
+        datetime.datetime.now(datetime.timezone.utc).isoformat()
+    )
     if auto:
         prefix += "auto_"
     target = tempfile.mktemp(suffix=".zip", prefix=prefix)
@@ -238,7 +240,7 @@ def gc_snapshots() -> None:
     snapshots = sorted([x for x in os.listdir(snapshot_dir) if x.endswith(".zip")])
     # Never GC the latest snapshot.
     snapshots = snapshots[:-1]
-    horizon = datetime.datetime.now() - datetime.timedelta(hours=1)
+    horizon = datetime.datetime.now(datetime.timezone.utc) - datetime.timedelta(hours=1)
     prefix = "snapshot_{}_".format(horizon.isoformat())
     # GC snapshots older than 1 hour.
     for snapshot in snapshots:
@@ -568,6 +570,21 @@ def setup_nfs():
             logger.exception(f"Error running {cmd}")
 
 
+def setup_vscode_desktop():
+    local_folder = "/home/ray/.vscode-server"
+    remote_folder = "/mnt/cluster_storage/vscode_desktop"
+
+    # create the local folder
+    os.makedirs(local_folder, exist_ok=True)
+
+    # create the remote sub folders and link them
+    sub_folders = ["data", "extensions"]
+    for folder in sub_folders:
+        directory = f"{remote_folder}/{folder}"
+        os.makedirs(directory, exist_ok=True)
+        os.symlink(directory, f"{local_folder}/{folder}")
+
+
 def setup_container(ray_params: Any, is_head: bool):
     """Setup the container synchronously prior to Ray start.
 
@@ -598,6 +615,10 @@ def setup_container(ray_params: Any, is_head: bool):
                 setup_credentials()
             except Exception:
                 logger.exception("Failed to setup SSH credentials")
+            try:
+                setup_vscode_desktop()
+            except Exception:
+                logger.exception("Failed to setup VSCode desktop")
     with open("/tmp/initialized", "w") as f:
         f.write("ok")
 
