@@ -223,6 +223,7 @@ def get_available_regions() -> List[str]:
 def launch_gcp_cloud_setup(
     name: str,
     region: str,
+    is_k8s: Optional[bool],
     folder_id: Optional[int],
     vpc_peering_ip_range: Optional[str],
     vpc_peering_target_project_id: Optional[str],
@@ -230,9 +231,11 @@ def launch_gcp_cloud_setup(
 ) -> None:
     # TODO: enforce uniqueness for user's clouds
     quote_safe_name = quote_sanitize(name, safe="")
-    query_params = {
+    query_params: Dict[str, Any] = {
         "region": region,
     }
+    if is_k8s is not None:
+        query_params["is_k8s"] = is_k8s
     if folder_id:
         query_params["folder_id"] = str(folder_id)
     if (
@@ -883,3 +886,8 @@ def credentials_check_sanity(credentials_str: str) -> bool:
 def get_current_cluster_id() -> Optional[str]:
     """If we are running on an Anyscale Cluster, return the id from the environment."""
     return os.getenv("ANYSCALE_SESSION_ID")
+
+
+def str_data_size(s: str) -> int:
+    """Returns the size of the string when encoded to raw bytes."""
+    return len(s.encode("utf-8"))
