@@ -3,6 +3,7 @@ import inspect
 from typing import Any, Callable, Dict, List, Optional
 
 from anyscale.client.openapi_client.models.session import Session
+from anyscale.sdk.anyscale_client.models.cluster import Cluster
 from anyscale.sdk.anyscale_client.sdk import AnyscaleSDK
 
 
@@ -56,15 +57,23 @@ def get_cluster(
     sdk: AnyscaleSDK, project_id: str, session_name: str
 ) -> Optional[Session]:
     """Query Anyscale for the given cluster's metadata."""
-    results = sdk.search_sessions(
-        project_id, {"name": {"equals": session_name}}
+    clusters = sdk.search_clusters(
+        {
+            "project_id": project_id,
+            "name": {"equals": session_name},
+            "archive_status": "ALL",
+        }
     ).results
-    cluster_found: Session = None
-    for session in results:
-        if session.name == session_name:
-            cluster_found = session
+    cluster_found: Optional[Cluster] = None
+    for cluster in clusters:
+        if cluster.name == session_name:
+            cluster_found = cluster
             break
-    return cluster_found
+
+    # A separate call is needed because downstream clients expect "Session" type
+    if cluster_found:
+        return sdk.get_session(cluster_found.id).result
+    return None
 
 
 def list_entities(
