@@ -1195,7 +1195,11 @@ def upload_and_rewrite_working_dir(
         [str, str, str], str
     ] = _upload_file_to_remote_storage,
 ) -> Dict[str, Any]:
-    """Upload a local working_dir and rewrite the working_dir field with the destination remote URI."""
+    """Upload a local working_dir and rewrite the working_dir field with the destination remote URI.
+
+    After uploading, deletes the "upload_path" field because it is no longer used and is not a valid
+    OSS runtime env field.
+    """
     if "working_dir" not in runtime_env_json:
         return runtime_env_json
 
@@ -1226,7 +1230,7 @@ def upload_and_rewrite_working_dir(
 
     final_runtime_env = runtime_env_json.copy()
     final_runtime_env["working_dir"] = final_uploaded_filepath
-
+    del final_runtime_env["upload_path"]
     return final_runtime_env
 
 
