@@ -1,5 +1,5 @@
 from typing import Any, Dict, List, Optional
-from unittest.mock import ANY, call, Mock, patch
+from unittest.mock import _Call, ANY, call, Mock, patch
 
 import pytest
 
@@ -30,7 +30,7 @@ def mock_prepare_cluster_block():
 
 @pytest.mark.parametrize("cluster_name", [None, "test_cluster_name"])
 @pytest.mark.parametrize("ray_cli_is_connected", [True, False])
-def test_create_cluster(
+def test_start_or_create_cluster(
     mock_prepare_cluster_block, cluster_name: Optional[str], ray_cli_is_connected: bool
 ):
     mock_prepare_cluster_block.anyscale_api_client.list_sessions = Mock(
@@ -39,9 +39,13 @@ def test_create_cluster(
     mock_prepare_cluster_block._ray.util.client.ray.is_connected = Mock(
         return_value=ray_cli_is_connected
     )
-    mock_prepare_cluster_block._start_cluster = Mock()
+    mock_cluster = Mock()
+    mock_prepare_cluster_block._create_or_update_session_data = Mock(
+        return_value=(mock_cluster, True)
+    )
+    mock_prepare_cluster_block._start_cluster_if_required = Mock()
 
-    mock_prepare_cluster_block._create_cluster(
+    mock_prepare_cluster_block._start_or_create_cluster(
         "test_project_id",
         "test_build_id",
         "test_compute_template_id",
@@ -56,28 +60,35 @@ def test_create_cluster(
         )
     if ray_cli_is_connected:
         mock_prepare_cluster_block._ray.util.disconnect.assert_called_once_with()
-    mock_prepare_cluster_block._start_cluster.assert_called_once_with(
-        project_id="test_project_id",
-        cluster_name=cluster_name if cluster_name else "cluster-0",
-        build_id="test_build_id",
-        compute_template_id="test_compute_template_id",
-        autosuspend_timeout=100,
-        allow_public_internet_traffic=None,
-        create_new_cluster=cluster_name is None,
+    mock_prepare_cluster_block._create_or_update_session_data.assert_called_once_with(
+        cluster_name if cluster_name else "cluster-0",
+        "test_project_id",
+        "test_build_id",
+        "test_compute_template_id",
+        100,
+        False,
+        not cluster_name,
+    )
+    mock_prepare_cluster_block._start_cluster_if_required.assert_called_once_with(
+        mock_cluster,
+        True,
+        "test_project_id",
+        "test_build_id",
+        "test_compute_template_id",
+        None,
     )
 
 
 @pytest.mark.parametrize("start_required", [True, False])
 @pytest.mark.parametrize("allow_public_internet_traffic", [True, False])
-@pytest.mark.parametrize("create_new_cluster", [True, False])
-def test_start_cluster(
+def test_start_cluster_if_required(
     mock_prepare_cluster_block,
     start_required: bool,
     allow_public_internet_traffic: bool,
-    create_new_cluster: bool,
 ):
     mock_cluster = Mock(id="test_cluster_id")
     mock_cluster.name = "test_cluster_name"
+
     mock_prepare_cluster_block._create_or_update_session_data = Mock(
         return_value=(mock_cluster, start_required)
     )
@@ -87,24 +98,14 @@ def test_start_cluster(
         "anyscale.connect_utils.prepare_cluster",
         wait_for_session_start=mock_wait_for_session_start,
     ):
-        mock_prepare_cluster_block._start_cluster(
+        mock_prepare_cluster_block._start_cluster_if_required(
+            mock_cluster,
+            start_required,
             "test_project_id",
-            "test_cluster_name",
             "test_build_id",
             "test_compute_template_id",
-            100,
             allow_public_internet_traffic,
-            create_new_cluster,
         )
-    mock_prepare_cluster_block._create_or_update_session_data.assert_called_once_with(
-        "test_cluster_name",
-        "test_project_id",
-        "test_build_id",
-        "test_compute_template_id",
-        100,
-        bool(allow_public_internet_traffic),
-        create_new_cluster=create_new_cluster,
-    )
     mock_prepare_cluster_block._log_cluster_configs.assert_called_once_with(
         mock_cluster, "test_build_id", "test_compute_template_id", ANY
     )
@@ -136,7 +137,9 @@ def test_create_or_update_session_data(
     idle_timeout: Optional[int],
 ):
     mock_cluster = Mock(state="Running", id="test_cluster_id")
-    mock_get_cluster = Mock(return_value=(mock_cluster if cluster_exists else None))
+    mock_get_cluster = Mock(
+        side_effect=[(mock_cluster if cluster_exists else None), mock_cluster]
+    )
     mock_prepare_cluster_block._validate_new_cluster_compute_and_env_match_existing_cluster = Mock(
         return_value=start_required
     )
@@ -153,13 +156,13 @@ def test_create_or_update_session_data(
             None,
         )
 
-    mock_get_cluster.assert_called_once_with(
-        mock_prepare_cluster_block.anyscale_api_client,
-        "test_project_id",
-        "test_cluster_name",
-    )
-
     if not cluster_exists:
+        mock_get_cluster.assert_called_with(
+            mock_prepare_cluster_block.anyscale_api_client,
+            "test_project_id",
+            "test_cluster_name",
+        )
+        assert mock_get_cluster.call_count == 2
         mock_prepare_cluster_block.anyscale_api_client.create_cluster.assert_called_once_with(
             CreateCluster(
                 name="test_cluster_name",
@@ -173,6 +176,11 @@ def test_create_or_update_session_data(
         mock_prepare_cluster_block.anyscale_api_client.update_cluster.assert_not_called()
         mock_prepare_cluster_block._validate_new_cluster_compute_and_env_match_existing_cluster.assert_not_called()
     else:
+        mock_get_cluster.assert_called_once_with(
+            mock_prepare_cluster_block.anyscale_api_client,
+            "test_project_id",
+            "test_cluster_name",
+        )
         mock_prepare_cluster_block.anyscale_api_client.create_cluster.assert_not_called()
         mock_prepare_cluster_block._validate_new_cluster_compute_and_env_match_existing_cluster.assert_called_once_with(
             "test_project_id", mock_cluster, print_warnings=False
@@ -186,15 +194,14 @@ def test_create_or_update_session_data(
 def test_create_or_update_session_data_generates_new_cluster_name(
     mock_prepare_cluster_block,
 ):
-    mock_taken_cluster_name = Mock(
+    mock_taken_cluster = Mock(
         state="Running", id="test_cluster_id", name="cluster-exists"
     )
-    mock_cluster = Mock(state="Running", id="test_cluster_id", name="cluster-newgen")
-    mock_prepare_cluster_block.anyscale_api_client.create_cluster.return_value = (
-        mock_cluster
+    mock_new_cluster = Mock(
+        state="Running", id="test_cluster_id", name="cluster-newgen"
     )
 
-    mock_get_cluster = Mock(side_effect=[mock_taken_cluster_name, None])
+    mock_get_cluster = Mock(side_effect=[mock_taken_cluster, None, mock_new_cluster])
     mock_prepare_cluster_block._validate_new_cluster_compute_and_env_match_existing_cluster = (
         Mock()
     )
@@ -222,8 +229,17 @@ def test_create_or_update_session_data_generates_new_cluster_name(
             call(
                 mock_prepare_cluster_block.anyscale_api_client, "test_project_id", ANY,
             ),
+            call(
+                mock_prepare_cluster_block.anyscale_api_client, "test_project_id", ANY,
+            ),
         ]
     )
+    # assert the newly generated cluster has a different name than the existing cluster
+    cluster_name_of_first_get_cluster_call = mock_get_cluster.call_args_list[0][0][-1]
+    cluster_name_of_last_get_cluster_call = mock_get_cluster.call_args_list[-1][0][-1]
+    assert (
+        cluster_name_of_first_get_cluster_call != cluster_name_of_last_get_cluster_call
+    )
 
     mock_prepare_cluster_block.anyscale_api_client.create_cluster.assert_called_once_with(
         CreateCluster(
@@ -243,7 +259,7 @@ def test_create_or_update_session_data_generates_new_cluster_name(
 @pytest.mark.parametrize("cluster_exists", [True, False])
 @pytest.mark.parametrize("cluster_name", ["test_cluster_name", None])
 @pytest.mark.parametrize("cluster_state", ["Running", "Other"])
-def test_check_if_cluster_needs_start(
+def test_check_if_cluster_needs_start_or_create(
     mock_prepare_cluster_block,
     needs_update: bool,
     cluster_exists: bool,
@@ -260,12 +276,12 @@ def test_check_if_cluster_needs_start(
     )
 
     if not cluster_name or cluster_state != "Running" or not cluster_exists:
-        assert mock_prepare_cluster_block._check_if_cluster_needs_start(
+        assert mock_prepare_cluster_block._check_if_cluster_needs_start_or_create(
             "test_project_id", cluster_name, needs_update
         )
     else:
         assert (
-            mock_prepare_cluster_block._check_if_cluster_needs_start(
+            mock_prepare_cluster_block._check_if_cluster_needs_start_or_create(
                 "test_project_id", cluster_name, needs_update
             )
             == needs_update
@@ -667,20 +683,22 @@ def test_get_all_clouds(mock_prepare_cluster_block) -> None:
     )
 
 
-@pytest.mark.parametrize("cluster_needs_start", [True, False])
+@pytest.mark.parametrize("cluster_needs_start_or_create", [True, False])
 @pytest.mark.parametrize("cluster_name", ["test_cluster_name", None])
 @pytest.mark.parametrize("cluster_compute_name", ["test_cluster_compute_name", None])
 @pytest.mark.parametrize("cluster_env_name", ["test_cluster_env_name", None])
 def test_init(
-    cluster_needs_start: bool,
+    cluster_needs_start_or_create: bool,
     cluster_name: Optional[str],
     cluster_compute_name: Optional[str],
     cluster_env_name: Optional[str],
 ):
-    if not cluster_needs_start and not cluster_name:
+    if not cluster_needs_start_or_create and not cluster_name:
         return
 
-    mock_check_if_cluster_needs_start = Mock(return_value=cluster_needs_start)
+    mock_check_if_cluster_needs_start_or_create = Mock(
+        return_value=cluster_needs_start_or_create
+    )
     mock_cluster = Mock(
         cloud_id="mock_cloud_id", compute_template_id="mock_cluster_compute_id"
     )
@@ -690,7 +708,7 @@ def test_init(
     mock_get_cloud_id = Mock(return_value="mock_cloud_id")
     mock_get_cluster_compute_id = Mock(return_value="mock_cluster_compute_id")
     mock_wait_for_app_build = Mock()
-    mock_create_cluster = Mock(return_value="test_cluster_name")
+    mock_start_or_create_cluster = Mock(return_value="test_cluster_name")
     mock_validate_new_cluster_compute_and_env_match_existing_cluster = Mock()
     mock_log_cluster_configs = Mock()
     mock_cluster_compute_dict = Mock()
@@ -702,13 +720,13 @@ def test_init(
         "anyscale.connect_utils.prepare_cluster.PrepareClusterBlock",
         _log_cluster_configs=mock_log_cluster_configs,
         _validate_new_cluster_compute_and_env_match_existing_cluster=mock_validate_new_cluster_compute_and_env_match_existing_cluster,
-        _create_cluster=mock_create_cluster,
+        _start_or_create_cluster=mock_start_or_create_cluster,
         _wait_for_app_build=mock_wait_for_app_build,
         _get_cluster_compute_id=mock_get_cluster_compute_id,
         _get_cloud_id=mock_get_cloud_id,
         _get_cluster_build=mock_get_cluster_build,
         _build_cluster_env_if_needed=mock_build_cluster_env_if_needed,
-        _check_if_cluster_needs_start=mock_check_if_cluster_needs_start,
+        _check_if_cluster_needs_start_or_create=mock_check_if_cluster_needs_start_or_create,
     ), patch.multiple(
         "anyscale.connect_utils.prepare_cluster",
         get_cluster=Mock(return_value=mock_cluster),
@@ -733,10 +751,10 @@ def test_init(
         )
         assert prepare_cluster_block.cluster_name == "test_cluster_name"
 
-    mock_check_if_cluster_needs_start.assert_called_once_with(
+    mock_check_if_cluster_needs_start_or_create.assert_called_once_with(
         "test_project_id", cluster_name, False
     )
-    if cluster_needs_start:
+    if cluster_needs_start_or_create:
         mock_build_cluster_env_if_needed.assert_called_once_with(
             "test_project_id",
             None,
@@ -762,7 +780,7 @@ def test_init(
                 "test_cloud_name",
             )
         mock_wait_for_app_build.assert_called_once_with("test_project_id", build_id)
-        mock_create_cluster.assert_called_once_with(
+        mock_start_or_create_cluster.assert_called_once_with(
             project_id="test_project_id",
             build_id=build_id,
             compute_template_id="mock_cluster_compute_id",
@@ -775,6 +793,59 @@ def test_init(
             project_id="test_project_id", running_cluster=mock_cluster
         )
         mock_log_cluster_configs.assert_called_once_with(
-            mock_cluster, mock_cluster.build_id, mock_cluster.compute_template_id, ANY
+            mock_cluster, mock_cluster.build_id, mock_cluster.compute_template_id, ANY,
         )
-        mock_create_cluster.assert_not_called()
+        mock_start_or_create_cluster.assert_not_called()
+
+
+@pytest.mark.parametrize("idle_timeout", [60, -1])
+@pytest.mark.parametrize("maximum_uptime_minutes", [60, -1])
+def test_log_cluster_configs(
+    mock_prepare_cluster_block, idle_timeout: int, maximum_uptime_minutes: int,
+) -> None:
+    mock_prepare_cluster_block.anyscale_api_client.get_build = Mock(
+        return_value=Mock(result=Mock(application_template_id="env_name", revision=1))
+    )
+    mock_compute_config_config = Mock(
+        id="id", config=Mock(maximum_uptime_minutes=maximum_uptime_minutes)
+    )
+    mock_compute_config_config.name = "config_name"
+    mock_prepare_cluster_block.anyscale_api_client.get_compute_template = Mock(
+        return_value=Mock(result=mock_compute_config_config)
+    )
+    mock_cluster = Mock(id="ses_1", idle_timeout=idle_timeout)
+    mock_build_id = "build_id"
+    mock_compute_template_id = "compute_template_id"
+    mock_url = "url"
+    mock_prepare_cluster_block._log_cluster_configs(
+        mock_cluster, mock_build_id, mock_compute_template_id, mock_url
+    )
+    mock_prepare_cluster_block.anyscale_api_client.get_build.assert_called_once_with(
+        mock_build_id
+    )
+    mock_prepare_cluster_block.anyscale_api_client.get_compute_template.assert_called_once_with(
+        mock_compute_template_id
+    )
+
+    def call_args_for_log_line(name: str, value: str) -> _Call:
+        return call(f"{' ' * 2}{(name + ':').ljust(30)}{value}", block_label="")
+
+    def get_auto_terminate_output(value: int) -> str:
+        return f"{value} minutes" if value > 0 else "disabled"
+
+    mock_prepare_cluster_block.log.info.assert_has_calls(
+        [
+            call_args_for_log_line("cluster id", "ses_1"),
+            call_args_for_log_line("cluster environment", "env_name:1"),
+            call_args_for_log_line("cluster environment id", "build_id"),
+            call_args_for_log_line("cluster compute", "config_name"),
+            call_args_for_log_line("cluster compute id", "compute_template_id"),
+            call_args_for_log_line(
+                "idle termination", get_auto_terminate_output(idle_timeout)
+            ),
+            call_args_for_log_line(
+                "maximum uptime", get_auto_terminate_output(maximum_uptime_minutes)
+            ),
+            call_args_for_log_line("link", "url"),
+        ]
+    )
