@@ -111,12 +111,13 @@ def test_setup_cloud_gcp() -> None:
     ):
         cloud_controller = CloudController()
         cloud_controller.setup_cloud(
-            provider="gcp", region=None, name="test-gcp", yes=True,
+            provider="gcp", region=None, name="test-gcp", yes=True, gce=True,
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
             region="us-west1",
             name="test-gcp",
+            is_k8s=False,
             folder_id=None,
             vpc_peering_ip_range=None,
             vpc_peering_target_project_id=None,
@@ -126,18 +127,44 @@ def test_setup_cloud_gcp() -> None:
         mock_launch_gcp_cloud_setup.reset_mock()
 
         cloud_controller.setup_cloud(
-            provider="gcp", region=None, name="test-gcp", yes=True, folder_id=1234,
+            provider="gcp",
+            region=None,
+            name="test-gcp",
+            yes=True,
+            folder_id=1234,
+            gce=False,
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
             region="us-west1",
             name="test-gcp",
+            is_k8s=True,
             folder_id=1234,
             vpc_peering_ip_range=None,
             vpc_peering_target_project_id=None,
             vpc_peering_target_vpc_id=None,
         )
 
+        mock_launch_gcp_cloud_setup.reset_mock()
+
+        cloud_controller.setup_cloud(
+            provider="gcp",
+            region="us-west2",
+            name="test-gcp",
+            yes=True,
+            folder_id=2345,
+        )
+
+        mock_launch_gcp_cloud_setup.assert_called_once_with(
+            region="us-west2",
+            name="test-gcp",
+            is_k8s=True,
+            folder_id=2345,
+            vpc_peering_ip_range=None,
+            vpc_peering_target_project_id=None,
+            vpc_peering_target_vpc_id=None,
+        )
+
 
 @pytest.mark.parametrize(
     "vpc_peering_options",
@@ -168,6 +195,7 @@ def test_setup_cloud_gcp_vpc_peering(
                     region=None,
                     name="test-gcp",
                     yes=True,
+                    gce=False,
                     vpc_peering_ip_range=vpc_peering_ip_range,
                     vpc_peering_target_project_id=vpc_peering_target_project_id,
                     vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
@@ -178,6 +206,7 @@ def test_setup_cloud_gcp_vpc_peering(
                 region=None,
                 name="test-gcp",
                 yes=True,
+                gce=False,
                 vpc_peering_ip_range=vpc_peering_ip_range,
                 vpc_peering_target_project_id=vpc_peering_target_project_id,
                 vpc_peering_target_vpc_id=vpc_peering_target_vpc_id,
@@ -189,6 +218,7 @@ def test_setup_cloud_gcp_vpc_peering(
         mock_launch_gcp_cloud_setup.assert_called_once_with(
             region="us-west1",
             name="test-gcp",
+            is_k8s=True,
             folder_id=None,
             vpc_peering_ip_range=vpc_peering_ip_range,
             vpc_peering_target_project_id=vpc_peering_target_project_id,
@@ -202,6 +232,7 @@ def test_setup_cloud_gcp_vpc_peering(
             region=None,
             name="test-gcp",
             yes=True,
+            gce=True,
             folder_id=1234,
             vpc_peering_ip_range=vpc_peering_ip_range,
             vpc_peering_target_project_id=vpc_peering_target_project_id,
@@ -211,6 +242,7 @@ def test_setup_cloud_gcp_vpc_peering(
         mock_launch_gcp_cloud_setup.assert_called_once_with(
             region="us-west1",
             name="test-gcp",
+            is_k8s=False,
             folder_id=1234,
             vpc_peering_ip_range=vpc_peering_ip_range,
             vpc_peering_target_project_id=vpc_peering_target_project_id,
