@@ -65,9 +65,10 @@ def test_get_project_id_and_cluster_name_given_cluster_id(mock_auth_api_client):
     cluster_controller._get_or_generate_cluster_name = Mock(  # type: ignore
         return_value="mock_cluster_name1"
     )
+    mock_get_and_validate_project_id = Mock(return_value="mock_project_id1")
     with patch.multiple(
         "anyscale.controllers.cluster_controller",
-        get_and_validate_project_id=Mock(return_value="mock_project_id1"),
+        get_and_validate_project_id=mock_get_and_validate_project_id,
     ):
         assert cluster_controller._get_project_id_and_cluster_name(
             cluster_id=None,
@@ -75,14 +76,21 @@ def test_get_project_id_and_cluster_name_given_cluster_id(mock_auth_api_client):
             cluster_name=None,
             project_name=None,
         ) == ("mock_project_id1", "mock_cluster_name1")
+        mock_get_and_validate_project_id.assert_called_once_with(
+            project_id="mock_project_id1",
+            project_name=None,
+            api_client=cluster_controller.api_client,
+            anyscale_api_client=cluster_controller.anyscale_api_client,
+        )
 
     # Test passing in project name
     cluster_controller._get_or_generate_cluster_name = Mock(  # type: ignore
         return_value="mock_cluster_name1"
     )
+    mock_get_and_validate_project_id.reset_mock()
     with patch.multiple(
         "anyscale.controllers.cluster_controller",
-        get_and_validate_project_id=Mock(return_value="mock_project_id1"),
+        get_and_validate_project_id=mock_get_and_validate_project_id,
     ):
         assert cluster_controller._get_project_id_and_cluster_name(
             cluster_id=None,
@@ -90,6 +98,12 @@ def test_get_project_id_and_cluster_name_given_cluster_id(mock_auth_api_client):
             cluster_name=None,
             project_name="mock_project_name1",
         ) == ("mock_project_id1", "mock_cluster_name1")
+        mock_get_and_validate_project_id.assert_called_once_with(
+            project_id=None,
+            project_name="mock_project_name1",
+            api_client=cluster_controller.api_client,
+            anyscale_api_client=cluster_controller.anyscale_api_client,
+        )
 
 
 def test_get_cluster_env_and_build(mock_auth_api_client):
