@@ -82,6 +82,8 @@ def test_convert_compute_config_aws(mock_auth_api_client) -> None:
             head_node_type={
                 "name": "head-1",
                 "instance_type": "m5.2xlarge",
+                "aws_advanced_configurations": None,
+                "gcp_advanced_configurations": None,
                 "resources": None,
             },
             worker_node_types=[
@@ -92,6 +94,9 @@ def test_convert_compute_config_aws(mock_auth_api_client) -> None:
                     "min_workers": None,
                     "max_workers": None,
                     "use_spot": False,
+                    "resources": None,
+                    "aws_advanced_configurations": None,
+                    "gcp_advanced_configurations": None,
                 },
                 {
                     "name": "worker-node-1",
@@ -100,6 +105,9 @@ def test_convert_compute_config_aws(mock_auth_api_client) -> None:
                     "min_workers": None,
                     "max_workers": None,
                     "use_spot": False,
+                    "resources": None,
+                    "aws_advanced_configurations": None,
+                    "gcp_advanced_configurations": None,
                 },
             ],
             aws={"TagSpecifications": "fake", "IamInstanceProfile": "fake2"},
