@@ -114,7 +114,8 @@ def test_submit_job(
     mock_auth_api_client, config_dict: Dict[str, Any], use_default_project: bool,
 ) -> None:
     config_project_id = config_dict.get("project_id")
-    job_controller = JobController()
+    mock_logger = Mock()
+    job_controller = JobController(log=mock_logger)
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
 
@@ -153,6 +154,10 @@ def test_submit_job(
         register_compute_template=mock_register_compute_template,
         validate_successful_build=mock_validate_successful_build,
         get_default_cluster_env_build=mock_get_default_cluster_env_build,
+    ), patch.object(
+        JobController,
+        "_get_maximum_uptime_output",
+        return_value="mock maximum uptime output",
     ), patch.multiple(
         "os.path", exists=Mock(return_value=True)
     ):
@@ -181,6 +186,7 @@ def test_submit_job(
             ),
         )
     )
+    assert mock_logger.info.call_count == 5
     if "cluster_env" not in config_dict and "build_id" not in config_dict:
         mock_get_default_cluster_env_build.assert_called_once_with()
     if "compute_config" in config_dict:
