@@ -1,7 +1,11 @@
 from datetime import datetime, timezone
 import json
+import os
+import random
+import shutil
+import string
 import tempfile
-from typing import Iterator, Optional, Tuple
+from typing import Any, Iterator, Optional, Tuple
 from unittest.mock import ANY, call, MagicMock, Mock, mock_open, patch
 
 import click
@@ -15,6 +19,7 @@ from anyscale.client.openapi_client import (
     ClusterConfig,
     ComputeTemplateConfig,
     CreateComputeTemplate,
+    LogdetailsResponse,
     Project,
     ProjectDefaultSessionName,
     ProjectdefaultsessionnameResponse,
@@ -28,6 +33,14 @@ from anyscale.client.openapi_client import (
     StartemptysessionresponseResponse,
     StopSessionOptions,
 )
+from anyscale.client.openapi_client.models import (
+    LogDetail,
+    LogDetails,
+    LogDownloadConfig,
+    LogDownloadRequest,
+    LogFilter,
+    NodeType,
+)
 from anyscale.controllers.session_controller import SessionController
 from anyscale.sdk.anyscale_client import (
     CreateSession,
@@ -1030,3 +1043,307 @@ def test_resolve_session(
     session_controller.api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
         session_test_data.project_id, name="session_name"
     )
+
+
+class AsyncBytesIterator:
+    def __init__(self, data: bytes, n: int) -> None:
+        self.data = data
+        self.n = n
+        self.read = 0
+
+    def __aiter__(self):  # type: ignore
+        return self
+
+    async def __anext__(self) -> bytes:
+        if not self.data[self.read :]:
+            raise StopAsyncIteration
+        _bytes = self.data[self.read : self.read + self.n]
+        self.read += self.n
+        return _bytes
+
+
+class AsyncStreamReader:
+    def __init__(self, _bytes: bytes) -> None:
+        self._bytes = _bytes
+
+    def iter_chunked(self, n: int) -> AsyncBytesIterator:
+        return AsyncBytesIterator(self._bytes, n)
+
+
+class AsyncMockResponse:
+    def __init__(self, resp: str, status: int) -> None:
+        self._bytes = bytes(resp, "utf-8")
+        self.status = status
+        self.content = AsyncStreamReader(self._bytes)
+
+    async def __aexit__(self, exc_type: Any, exc: Any, tb: Any) -> None:
+        pass
+
+    async def __aenter__(self):  # type: ignore
+        return self
+
+    async def text(self):  # type: ignore
+        return self._bytes.decode("utf-8")
+
+
+def test_download_log_files(mock_auth_api_client) -> None:  # type: ignore
+    """Test that the download_log_files is able to download files correctly.
+    Also verify handling of error response while downloading files.
+    Also test handling of paginated response.
+    """
+    session_controller = SessionController()
+    data = ["".join(random.choices(string.ascii_lowercase, k=5)) for x in range(2)]
+    data.append("error response")
+    dirpath = tempfile.mkdtemp()
+    try:
+        session_controller.api_client.get_log_files_api_v2_sessions_session_id_get_log_files_post.side_effect = [
+            LogdetailsResponse(
+                result=LogDetails(
+                    log_files=[
+                        LogDetail(
+                            name="logs/test1.txt",
+                            download_url="http://test.com",
+                            size=len(data[0]),
+                        )
+                    ],
+                    next_page_token="foo",
+                )
+            ),
+            LogdetailsResponse(
+                result=LogDetails(
+                    log_files=[
+                        LogDetail(
+                            name="logs/test2.txt",
+                            download_url="http://test.com",
+                            size=len(data[1]),
+                        ),
+                        LogDetail(
+                            name="logs/test3.txt",
+                            download_url="http://test.com",
+                            size=len(data[2]),
+                        ),
+                    ],
+                    next_page_token=None,
+                )
+            ),
+        ]
+
+        with patch(
+            "aiohttp.ClientSession.get",
+            side_effect=[
+                AsyncMockResponse(data[0], 200),
+                AsyncMockResponse(data[1], 200),
+                AsyncMockResponse(data[2], 500),
+            ],
+        ):
+            session_controller.download_log_files(base_folder=dirpath)
+        with open(f"{dirpath}/logs/test1.txt") as f:
+            assert f.readlines() == [data[0]]
+        with open(f"{dirpath}/logs/test2.txt") as f:
+            assert f.readlines() == [data[1]]
+        assert not os.path.exists(f"{dirpath}/logs/test3.txt")
+        assert (
+            session_controller.api_client.get_log_files_api_v2_sessions_session_id_get_log_files_post.call_args_list
+            == [
+                call(
+                    "latest",
+                    log_download_request=LogDownloadRequest(
+                        filter=LogFilter(
+                            glob=None,
+                            node_id=None,
+                            job_id=None,
+                            job_run=None,
+                            node_type=None,
+                        ),
+                        config=LogDownloadConfig(
+                            next_page_token=None, page_size=None, ttl_seconds=None,
+                        ),
+                    ),
+                ),
+                call(
+                    "latest",
+                    log_download_request=LogDownloadRequest(
+                        filter=LogFilter(
+                            glob=None,
+                            node_id=None,
+                            job_id=None,
+                            job_run=None,
+                            node_type=None,
+                        ),
+                        config=LogDownloadConfig(
+                            next_page_token="foo", page_size=None, ttl_seconds=None,
+                        ),
+                    ),
+                ),
+            ]
+        )
+
+    finally:
+        shutil.rmtree(dirpath)
+
+
+def test_download_log_files_params(mock_auth_api_client) -> None:  # type: ignore
+    """Test that when download_log_files is called with parameters then it invokes the get_log_files_api_v2 with the right set of parameters.
+    Also ensure that the parameters are passed correctly on the second call of pagination.
+    """
+    session_controller = SessionController()
+    data = ["".join(random.choices(string.ascii_lowercase, k=5)) for _ in range(2)]
+    dirpath = tempfile.mkdtemp()
+    try:
+        session_controller.api_client.get_log_files_api_v2_sessions_session_id_get_log_files_post.side_effect = [
+            LogdetailsResponse(
+                result=LogDetails(
+                    log_files=[
+                        LogDetail(
+                            name="logs/test1.txt",
+                            download_url="http://test.com",
+                            size=len(data[0]),
+                        )
+                    ],
+                    next_page_token="foo",
+                )
+            ),
+            LogdetailsResponse(
+                result=LogDetails(
+                    log_files=[
+                        LogDetail(
+                            name="logs/test2.txt",
+                            download_url="http://test.com",
+                            size=len(data[1]),
+                        )
+                    ],
+                    next_page_token=None,
+                )
+            ),
+        ]
+
+        with patch(
+            "aiohttp.ClientSession.get",
+            side_effect=[
+                AsyncMockResponse(data[0], 200),
+                AsyncMockResponse(data[1], 200),
+            ],
+        ):
+            session_controller.download_log_files(
+                base_folder=dirpath,
+                glob="glob",
+                session_id="session_id",
+                node_id="node_id",
+                job_id="job_id",
+                job_run="job_run",
+                node_type=NodeType.HEAD_NODE,
+                page_size=10,
+                ttl_seconds=20,
+            )
+        session_controller.api_client.get_log_files_api_v2_sessions_session_id_get_log_files_post.call_args_list == [
+            call(
+                "session_id",
+                log_download_request=LogDownloadRequest(
+                    filter=LogFilter(
+                        glob="glob",
+                        node_id="node_id",
+                        job_id="job_id",
+                        job_run="job_run",
+                        node_type=NodeType.HEAD_NODE,
+                    ),
+                    config=LogDownloadConfig(
+                        next_page_token=None, page_size=10, ttl_seconds=20,
+                    ),
+                ),
+            ),
+            call(
+                "session_id",
+                log_download_request=LogDownloadRequest(
+                    filter=LogFilter(
+                        glob="glob",
+                        node_id="node_id",
+                        job_id="job_id",
+                        job_run="job_run",
+                        node_type=NodeType.HEAD_NODE,
+                    ),
+                    config=LogDownloadConfig(
+                        next_page_token="foo", page_size=10, ttl_seconds=20,
+                    ),
+                ),
+            ),
+        ]
+    finally:
+        shutil.rmtree(dirpath)
+
+
+def test_download_ray_result_files(mock_auth_api_client) -> None:  # type: ignore
+    """Test that the download_ray_result_files is able to download files correctly.
+    Also verify handling of error response while downloading files.
+    """
+    session_controller = SessionController()
+    data = ["".join(random.choices(string.ascii_lowercase, k=5))]
+    data.append("error response")
+    dirpath = tempfile.mkdtemp()
+    try:
+        session_controller.api_client.get_ray_result_files_api_v2_sessions_session_id_get_ray_result_files_get.return_value = LogdetailsResponse(
+            result=LogDetails(
+                log_files=[
+                    LogDetail(
+                        name="logs/test1.txt",
+                        download_url="http://test.com",
+                        size=len(data[0]),
+                    ),
+                    LogDetail(
+                        name="logs/test2.txt",
+                        download_url="http://test.com",
+                        size=len(data[0]),
+                    ),
+                ],
+                next_page_token="foo",
+            )
+        )
+
+        with patch(
+            "aiohttp.ClientSession.get",
+            side_effect=[
+                AsyncMockResponse(data[0], 200),
+                AsyncMockResponse(data[1], 500),
+            ],
+        ):
+            session_controller.download_ray_result_files(base_folder=dirpath)
+        with open(f"{dirpath}/logs/test1.txt") as f:
+            assert f.readlines() == [data[0]]
+        assert not os.path.exists(f"{dirpath}/logs/test2.txt")
+        session_controller.api_client.get_ray_result_files_api_v2_sessions_session_id_get_ray_result_files_get.assert_called_once_with(
+            "latest", job_id=None, job_run=None
+        )
+    finally:
+        shutil.rmtree(dirpath)
+
+
+def test_download_ray_result_files_params(mock_auth_api_client) -> None:  # type: ignore
+    """Test that the download_ray_result_files passed the parameters correctly to download_ray_result_files_api.
+    """
+    session_controller = SessionController()
+    data = "".join(random.choices(string.ascii_lowercase, k=5))
+    dirpath = tempfile.mkdtemp()
+    try:
+        session_controller.api_client.get_ray_result_files_api_v2_sessions_session_id_get_ray_result_files_get.return_value = LogdetailsResponse(
+            result=LogDetails(
+                log_files=[
+                    LogDetail(
+                        name="logs/test1.txt",
+                        download_url="http://test.com",
+                        size=len(data),
+                    )
+                ],
+                next_page_token=None,
+            )
+        )
+
+        with patch(
+            "aiohttp.ClientSession.get", side_effect=[AsyncMockResponse(data, 200)],
+        ):
+            session_controller.download_ray_result_files(
+                dirpath, "session_id", "job_id", "job_run"
+            )
+        session_controller.api_client.get_ray_result_files_api_v2_sessions_session_id_get_ray_result_files_get.assert_called_once_with(
+            "session_id", job_id="job_id", job_run="job_run"
+        )
+    finally:
+        shutil.rmtree(dirpath)
